allib.machinelearning package
=============================

Submodules
----------

allib.machinelearning.base module
---------------------------------

.. automodule:: allib.machinelearning.base
   :members:
   :undoc-members:
   :show-inheritance:

allib.machinelearning.catalog module
------------------------------------

.. automodule:: allib.machinelearning.catalog
   :members:
   :undoc-members:
   :show-inheritance:

allib.machinelearning.factory module
------------------------------------

.. automodule:: allib.machinelearning.factory
   :members:
   :undoc-members:
   :show-inheritance:

allib.machinelearning.sklearn module
------------------------------------

.. automodule:: allib.machinelearning.sklearn
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: allib.machinelearning
   :members:
   :undoc-members:
   :show-inheritance:
